/**
 * Common properties for all components
 */
export declare const commonProps: {
    /**
     * prop: 'src'
     * Audio element src attribute. When provided creates audio element
     */
    src: {
        type: StringConstructor;
        default: null;
    };
    /**
     * prop: 'audio-controls'
     * Audio element controls attribute. When provided should
     * display audio element with controls
     */
    audioControls: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * prop: 'cors-anonym'
     * CORS requests for this element will not have the credentials flag set.
     * Set crossOrigin property of audio element to 'anonymous'.
     * Default: null
     */
    corsAnonym: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * prop: 'canv-width'
     * Canvas element width. Default 300
     */
    canvWidth: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * prop: 'canv-height'
     * Canvas element height. Default 80
     */
    canvHeight: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * prop: 'canv-fill-color'
     * Canvas fill background color. Can be string RGB color or canvas gradients array.
     * Default is transparent.
     */
    canvFillColor: {
        type: (StringConstructor | ArrayConstructor)[];
        default: string;
    };
    /**
     * prop: 'placeholder'
     * Draw initial state of visualization. Like line in the middle for line plugin.
     * Default is true
     */
    placeholder: {
        type: BooleanConstructor;
        default: boolean;
    };
};
